@@ -10,33 +10,28 @@ class Config:
     # noinspection PyUnresolvedReferences
     """Abstract class to load a configuration. Basically just a wrapper around a json file.
 
-        This class should be overloaded and not used as-is, for only keys present in
-        `Config.EXPECTED_CONFIGS` and `Config.ADDITIONNAL_CONFIGS` will
-        be accepted from the json file, attribute that is empty in this abstract class. Any key present in
-        `Config.EXPECTED_CONFIGS` must be present in the json file. Any key present in
-        `Config.ADDITIONNAL_CONFIGS` can be present in the file.
+    This class should be overloaded and not used as-is, for only keys present in
+    `Config.EXPECTED_CONFIGS` and `Config.ADDITIONNAL_CONFIGS` will
+    be accepted from the json file, attribute that is empty in this abstract class. Any key present in
+    `Config.EXPECTED_CONFIGS` must be present in the json file. Any key present in
+    `Config.ADDITIONNAL_CONFIGS` can be present in the file.
 
-        The json file can be on GCP, the use of transparentpath is supported.
+    The json file can be on GCP, the use of transparentpath is supported.
 
-        Attributes
-        ----------
-        path: TransparentPath
-            The path to the json file containing the configuration. Will be casted into a transparentpath if a str is
-            given, so make sure that if you pass a string that should be local, you did not set a global file system.
-        configs: dict
-            Content of the json file. Any pair of key value present in it will be seen as an attribute of the class
-            instance and can be accessed by doing
-            >>> conf = MyConfig(path)
-            >>> conf.some_key
-            assuming MyConfig overloads this class and path points to a valid json file containing the key 'some_key'
+    Attributes
+    ----------
+    path: TransparentPath
+        The path to the json file containing the configuration. Will be casted into a transparentpath if a str is
+        given, so make sure that if you pass a string that should be local, you did not set a global file system.
+    configs: dict
+        Content of the json file. Any pair of key value present in it will be seen as an attribute of the class
+        instance and can be accessed by doing
 
-        Methods
-        -------
-         `save()`-> None\n
-            Saves the current configuration into the file it used to load. This allows the user to change the
-            configuration in code and save it. Note that one can not have added a key not present in
-            `Config.EXPECTED_CONFIGS`
-        """
+        >>> conf = MyConfig(path)
+        >>> conf.some_key
+
+        assuming *MyConfig* overloads this class and *path* points to a valid json file containing the key *some_key*
+    """
 
     EXPECTED_CONFIGS = []
     """Configuration keys that MUST figure in the json file"""
@@ -88,8 +83,10 @@ class Config:
             raise ValueError(f"No configuration named '{item}' is not allowed")
         self.configs[item] = value
 
-    def save(self):
-        """Saves the configuration back to the json file it was read from."""
+    def save(self) -> None:
+        """Saves the current configuration into the file it used to load. This allows the user to change the
+        configuration in code and save it. Note that one can not have added a key not present in
+        `Config.EXPECTED_CONFIGS`"""
         to_save = copy(self.configs)
 
         for key in to_save:
@@ -109,7 +106,7 @@ class NodePublicConfig(Config):
     Used by `ifra.node.Node` and `ifra.central_server.NodeGate`
 
     Overloads \_\_eq\_\_ to allow for node configuration comparison. Two configurations are equal if all their
-    configuration values are equal, except ''local_model_path'' and ''central_model_path'' that can be different.
+    configuration values are equal, except *local_model_path* and *central_model_path* that can be different.
 
     Attributes
     ----------
@@ -120,18 +117,18 @@ class NodePublicConfig(Config):
 
     features_names: List[str]
         Names of the features used in the learning. It should contain all the features, not only those available to
-        this node. If not specified, the json file should still contain the key 'features_names', but with value "".
+        this node. If not specified, the json file should still contain the key *features_names*, but with value "".
     classes_names: List[str]
         Names of the classes used in the learning. It should contain all the classes, not only those available to
-        this node. If not specified, the json file should still contain the key 'classes_names', but with value "".
+        this node. If not specified, the json file should still contain the key *classes_names*, but with value "".
     x_mins: Union[None, List[Union[int, float]]]
         Mmin values of each feature. Here too, if not None, should contain one entry for each
         feature used in the learning, and not only this node. If not specified, the json file should still contain the
-        key 'x_mins', but with value "".
+        key *x_mins*, but with value "".
     x_maxs: Union[None, List[Union[int, float]]]
         Max values of each feature. Here too, if not None, should contain one entry for each
         feature used in the learning, and not only this node. If not specified, the json file should still contain the
-        key 'x_maxs', but with value "".
+        key *x_maxs*, but with value "".
     max_depth: int
         Maximum depth of the decision tree to use in the model
     remember_activation: bool
@@ -147,19 +144,23 @@ class NodePublicConfig(Config):
         If True, will only consider the leaf ofthe tree to create rules. If False, every node of the tree will also be
         a rule.
     local_model_path: TransparentPath
-        Path where the node is supposed to write its model. Should point to a csv file.
+        Path where the node is supposed to write its model. Should point to a csv file to which the central server have
+        access.
     central_model_path: TransparentPath
         Path where the node is supposed to look for the central model. Should point to a csv file.
     dataprep_method: Union[str]
         Name of the method used to do dataprep. The given string must be importable from the current working directry.
         Will be None if "" is given. If not specified, the json file should still contain the
-        key 'dataprep_method', but with value "".
+        key *dataprep_method*, but with value "".
     id: Union[None, int, str]
         Name or number of the node. If not specified, will be set by central server. If not specified, the json file
-        should still contain the key 'id', but with value "".
+        should still contain the key *id*, but with value "".
     fitter: str
         Fitter to use. Can be one of :\n
-          * decisiontree\n
+          * decisiontree (see `ifra.fitter.DecisionTreeFitter`)\n
+    updater: str
+        Update method to be used by the node to take the central model into account. Can be one of:\n
+          * adaboost (see `ifra.updaters.AdaboostUpdater`)\n
     stop: bool
         Set to True by `ifra.central_server.CentralServer` when the learning is over.
     """
@@ -178,7 +179,8 @@ class NodePublicConfig(Config):
         "central_model_path",
         "dataprep_method",
         "id",
-        "fitter"
+        "fitter",
+        "updater"
     ]
     ADDITIONNAL_CONFIGS = ["stop"]
 
@@ -218,6 +220,8 @@ class CentralConfig(Config):
     output_path: TransparentPath
         Path where the central server will save its model at the end of the learning. Will also produce one output each
         time the model is updated. Should point to a csv file.
+    output_path_fs: str
+        File system to use for learning outpout. Can be 'gcs', 'local' or ""
     min_number_of_new_models: int
         Minimum number of nodes that must have prodived a new model to trigger aggregation.
     """
@@ -225,16 +229,22 @@ class CentralConfig(Config):
     EXPECTED_CONFIGS = [
         "max_coverage",
         "output_path",
+        "output_path_fs",
         "min_number_of_new_models"
     ]
 
     def __init__(self, path: Union[str, Path, TransparentPath]):
         super().__init__(path)
         if isinstance(self.configs["output_path"], str):
-            self.configs["output_path"] = TransparentPath(self.configs["output_path"])
+            if self.configs["output_path_fs"] is not None:
+                self.configs["output_path"] = TransparentPath(
+                    self.configs["output_path"], fs=self.configs["output_path_fs"]
+                )
+            else:
+                self.configs["output_path"] = TransparentPath(self.configs["output_path"])
 
 
-class Paths(Config):
+class NodeDataConfig(Config):
     # noinspection PyUnresolvedReferences
     """Overloads `Config`, corresponding to one node data paths configuration. Not accessible by
     the central server.
@@ -262,13 +272,17 @@ class Paths(Config):
         y_read_kwargs should contain index_col=0
     x_read_kwargs: Union[None, dict]
         Keyword arguments to read the features file. If not specified, the json file should still contain the key
-        'x_read_kwargs', but with value "".
+        *x_read_kwargs*, but with value "".
     y_read_kwargs: Union[None, dict]
         Keyword arguments to read the target file. If not specified, the json file should still contain the key
-        'x_read_kwargs', but with value "".
+        *x_read_kwargs*, but with value "".
+    x_fs: str
+        File system to use for x file. Can be 'gcs', 'local' or ""
+    y_fs: str
+        File system to use for y file. Can be 'gcs', 'local' or ""
     """
 
-    EXPECTED_CONFIGS = ["x", "y", "x_read_kwargs", "y_read_kwargs"]
+    EXPECTED_CONFIGS = ["x", "y", "x_read_kwargs", "y_read_kwargs", "x_fs", "y_fs"]
 
     def __init__(self, path: Union[str, Path, TransparentPath]):
         super().__init__(path)
@@ -291,4 +305,8 @@ class Paths(Config):
 
         for item in self.configs:
             if isinstance(self.configs[item], str):
-                self.configs[item] = TransparentPath(self.configs[item])
+                fs = f"{item}_fs"
+                if fs in self.configs and self.configs[fs] is not None:
+                    self.configs[item] = TransparentPath(self.configs[item], fs=self.configs[fs])
+                else:
+                    self.configs[item] = TransparentPath(self.configs[item])
